config = {
    "covid_df": "https://raw.githubusercontent.com/nytimes/covid-19-data/master/us-counties.csv",
    "pop_df":"https://www2.census.gov/programs-surveys/popest/datasets/2010-2019/counties/totals/co-est2019-alldata.csv"
}
